@@ -44,7 +44,7 @@ class MoveTimeSlotIn(BaseMessage):
 
     action: Action = Action.MOVE_TIME_SLOT
     zone_id: int
-    timeslot: str
+    bucket_key: str
 
 
 class TriageScheduleIn(BaseMessage):
@@ -66,7 +66,6 @@ class PushPlaylistIn(BaseMessage):
     action: Action = Action.PUSH_PLAYLIST
     zone_id: int
     playlist_ids: list[int]
-    bucket_ts: BucketTS 
     expire_at: datetime | None = Field(
         default=None, description="The datetime that the playlist will expire"
     )
@@ -78,7 +77,7 @@ class PushPlaylistExpireIn(BaseMessage):
     action: Action = Action.EXPIRE_PUSHED_PLAYLIST
     zone_id: int
     new_mode: Literal["pushplaylist", "scheduled"] = "scheduled"
-    bucket_ts: BucketTS | None = None
+    bucket_key: BucketTS | None = None
 
 
 class RefreshTrackBucketIn(BaseMessage):
@@ -86,7 +85,7 @@ class RefreshTrackBucketIn(BaseMessage):
 
     action: Action = Action.REFRESH_TRACK_BUCKET
     zone_id: int
-    bucket_ts: BucketTS
+    bucket_key: str
 
 
 class RecalculateScheduleIn(BaseMessage):
@@ -103,6 +102,7 @@ class BanTrackIn(BaseMessage):
     zone_id: int
     track_id: UUID
     playlist_id: int
+    bucket_key: str
 
 
 class ZoneActivityIn(BaseMessage):
